==> blancoMessage-0.1.9-src.zip: blancoMessage/blanco.cs/main/blanco/sample/message/SampleMessage.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.message
{
    /// <summary>bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleMessage
    {
        /// <summary>[bZ[W̃TvB̂PB]</summary>
        /// <remarks>
        /// <newpara>No.1: </newpara>
        /// </remarks>
        public static readonly string MESSAGE001 = "bZ[W̃TvB̂PB";

        /// <summary>[bZ[Wu[{0}]u܂B]</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// </remarks>
        public static readonly string MESSAGE002 = "bZ[Wu[{0}]u܂B";

        /// <summary>[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// </remarks>
        public static readonly string MESSAGE003 = "bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B";

        /// <summary>[AbZ[Wu{0}{1}̗łB]</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// </remarks>
        public static readonly string MESSAGE004 = "AbZ[Wu{0}{1}̗łB";

        /// <summary>[{0}擪u񂪂B]</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// </remarks>
        public static readonly string MESSAGE005 = "{0}擪u񂪂B";

        /// <summary>[Ōオu̗B{0}]</summary>
        /// <remarks>
        /// <newpara>No.6: </newpara>
        /// </remarks>
        public static readonly string MESSAGE006 = "Ōオu̗B{0}";

        /// <summary>[xu{0}{1}{0}{1}{2}{1}{0}]</summary>
        /// <remarks>
        /// <newpara>No.7: </newpara>
        /// </remarks>
        public static readonly string MESSAGE007 = "xu{0}{1}{0}{1}{2}{1}{0}";

        /// <summary>[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// </remarks>
        public static readonly string MESSAGE008 = "̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B";

        /// <summary>[ԍԂƒu{1}B0IWłB]</summary>
        /// <remarks>
        /// <newpara>No.9: </newpara>
        /// </remarks>
        public static readonly string MESSAGE009 = "ԍԂƒu{1}B0IWłB";

        /// <summary>[GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]</summary>
        /// <remarks>
        /// <newpara>No.10: </newpara>
        /// </remarks>
        public static readonly string MESSAGE010 = "GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";

        /// <summary>[~]</summary>
        /// <remarks>
        /// <newpara>No.11: </newpara>
        /// </remarks>
        public static readonly string MESSAGE011 = "~";

        /// <summary>[s[\n]̎B]</summary>
        /// <remarks>
        /// <newpara>No.12: </newpara>
        /// </remarks>
        public static readonly string MESSAGE012 = "s[\n]̎B";

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.1: </newpara>
        /// <newpara>[bZ[W̃TvB̂PB]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage001()
        {
            return "bZ[W̃TvB̂PB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// <newpara>[bZ[Wu[{0}]u܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage002(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "bZ[Wu[" + arg0 + "]u܂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// <newpara>[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage003(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "bZ[Wu[" + arg0 + "]ɉAЂƂ[" + arg1 + "]u܂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// <newpara>[AbZ[Wu{0}{1}̗łB]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage004(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "AbZ[Wu" + arg0 + arg1 + "̗łB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// <newpara>[{0}擪u񂪂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage005(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return arg0 + "擪u񂪂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.6: </newpara>
        /// <newpara>[Ōオu̗B{0}]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage006(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "Ōオu̗B" + arg0;
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.7: </newpara>
        /// <newpara>[xu{0}{1}{0}{1}{2}{1}{0}]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage007(string arg0, string arg1, string arg2)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "xu" + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0;
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// <newpara>[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <param name="arg3">u{3}̒lB</param>
        /// <param name="arg4">u{4}̒lB</param>
        /// <param name="arg5">u{5}̒lB</param>
        /// <param name="arg6">u{6}̒lB</param>
        /// <param name="arg7">u{7}̒lB</param>
        /// <param name="arg8">u{8}̒lB</param>
        /// <param name="arg9">u{9}̒lB</param>
        /// <param name="arg10">u{10}̒lB</param>
        /// <param name="arg11">u{11}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage008(string arg0, string arg1, string arg2, string arg3, string arg4, string arg5, string arg6, string arg7, string arg8, string arg9, string arg10, string arg11)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg3 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg4 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg5 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg6 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg7 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg8 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg9 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg10 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg11 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "̒uB" + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + "12B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.9: </newpara>
        /// <newpara>[ԍԂƒu{1}B0IWłB]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage009()
        {
            return "ԍԂƒu{1}B0IWłB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.10: </newpara>
        /// <newpara>[GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage010()
        {
            return "GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.11: </newpara>
        /// <newpara>[~]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage011()
        {
            return "~";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.12: </newpara>
        /// <newpara>[s[\n]̎B]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage012()
        {
            return "s[\n]̎B";
        }
    }
}

==> blancoMessage-0.4.0-src.zip: blancoMessage/blanco.cs/main/blanco/sample/message/SampleMessage.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.message
{
    /// <summary>bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B</summary>
    public class SampleMessage
    {
        /// <summary>[bZ[W̃TvB̂PB]</summary>
        /// <remarks>
        /// <newpara>No.1: </newpara>
        /// </remarks>
        public static readonly string MESSAGE001 = "bZ[W̃TvB̂PB";

        /// <summary>[bZ[Wu[{0}]u܂B]</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// </remarks>
        public static readonly string MESSAGE002 = "bZ[Wu[{0}]u܂B";

        /// <summary>[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// </remarks>
        public static readonly string MESSAGE003 = "bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B";

        /// <summary>[AbZ[Wu{0}{1}̗łB]</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// </remarks>
        public static readonly string MESSAGE004 = "AbZ[Wu{0}{1}̗łB";

        /// <summary>[{0}擪u񂪂B]</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// </remarks>
        public static readonly string MESSAGE005 = "{0}擪u񂪂B";

        /// <summary>[Ōオu̗B{0}]</summary>
        /// <remarks>
        /// <newpara>No.6: </newpara>
        /// </remarks>
        public static readonly string MESSAGE006 = "Ōオu̗B{0}";

        /// <summary>[xu{0}{1}{0}{1}{2}{1}{0}]</summary>
        /// <remarks>
        /// <newpara>No.7: </newpara>
        /// </remarks>
        public static readonly string MESSAGE007 = "xu{0}{1}{0}{1}{2}{1}{0}";

        /// <summary>[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// </remarks>
        public static readonly string MESSAGE008 = "̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B";

        /// <summary>[{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]</summary>
        /// <remarks>
        /// <newpara>No.9: </newpara>
        /// </remarks>
        public static readonly string MESSAGE009 = "{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB";

        /// <summary>[GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]</summary>
        /// <remarks>
        /// <newpara>No.10: </newpara>
        /// </remarks>
        public static readonly string MESSAGE010 = "GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";

        /// <summary>[~]</summary>
        /// <remarks>
        /// <newpara>No.11: </newpara>
        /// </remarks>
        public static readonly string MESSAGE011 = "~";

        /// <summary>[s[\n]̎B]</summary>
        /// <remarks>
        /// <newpara>No.12: </newpara>
        /// </remarks>
        public static readonly string MESSAGE012 = "s[\n]̎B";

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.1: </newpara>
        /// <newpara>[bZ[W̃TvB̂PB]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage001()
        {
            return "bZ[W̃TvB̂PB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.2: </newpara>
        /// <newpara>[bZ[Wu[{0}]u܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage002(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "bZ[Wu[" + arg0 + "]u܂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.3: </newpara>
        /// <newpara>[bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage003(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "bZ[Wu[" + arg0 + "]ɉAЂƂ[" + arg1 + "]u܂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.4: </newpara>
        /// <newpara>[AbZ[Wu{0}{1}̗łB]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage004(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "AbZ[Wu" + arg0 + arg1 + "̗łB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.5: </newpara>
        /// <newpara>[{0}擪u񂪂B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage005(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return arg0 + "擪u񂪂B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.6: </newpara>
        /// <newpara>[Ōオu̗B{0}]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage006(string arg0)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "Ōオu̗B" + arg0;
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.7: </newpara>
        /// <newpara>[xu{0}{1}{0}{1}{2}{1}{0}]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage007(string arg0, string arg1, string arg2)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "xu" + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0;
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.8: </newpara>
        /// <newpara>[̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <param name="arg2">u{2}̒lB</param>
        /// <param name="arg3">u{3}̒lB</param>
        /// <param name="arg4">u{4}̒lB</param>
        /// <param name="arg5">u{5}̒lB</param>
        /// <param name="arg6">u{6}̒lB</param>
        /// <param name="arg7">u{7}̒lB</param>
        /// <param name="arg8">u{8}̒lB</param>
        /// <param name="arg9">u{9}̒lB</param>
        /// <param name="arg10">u{10}̒lB</param>
        /// <param name="arg11">u{11}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage008(string arg0, string arg1, string arg2, string arg3, string arg4, string arg5, string arg6, string arg7, string arg8, string arg9, string arg10, string arg11)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg2 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg3 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg4 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg5 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg6 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg7 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg8 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg9 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg10 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg11 == null) {
                throw new ArgumentException("\bh[GetMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return "̒uB" + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + "12B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.9: </newpara>
        /// <newpara>[{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]</newpara>
        /// </remarks>
        /// <param name="arg0">u{0}̒lB</param>
        /// <param name="arg1">u{1}̒lB</param>
        /// <returns>bZ[WB</returns>
        public string GetMessage009(string arg0, string arg1)
        {
            if (arg0 == null) {
                throw new ArgumentException("\bh[GetMessage009]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }
            if (arg1 == null) {
                throw new ArgumentException("\bh[GetMessage009]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            return arg0 + "ԍԂƒu͕sƂĔf܂B" + arg1 + "B̒`0IWłB";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.10: </newpara>
        /// <newpara>[GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage010()
        {
            return "GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.11: </newpara>
        /// <newpara>[~]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage011()
        {
            return "~";
        }

        /// <summary>bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B</summary>
        /// <remarks>
        /// <newpara>No.12: </newpara>
        /// <newpara>[s[\n]̎B]</newpara>
        /// </remarks>
        /// <returns>bZ[WB</returns>
        public string GetMessage012()
        {
            return "s[\n]̎B";
        }
    }
}
